@@ -20,11 +20,23 @@
 #'   like the default time zone, encoding, decimal mark, big mark, and day/month
 #'   names.
 #'
-#' @return A source_spct object.
+#' @return A \code{source_spct} object.
 #' @export
-#' @references \url{https://www.r4photobiology.info} \url{http://www.irradian.co.uk/}
-#' @keywords misc
-#'
+#' @references \url{https://www.irradian.co.uk/}
+#' 
+#' @examples
+#' 
+#'  file.name <- 
+#'    system.file("extdata", "spectrum.DTA", 
+#'                package = "photobiologyInOut", mustWork = TRUE)
+#'                 
+#'  macam.spct <- read_macam_dta(file = file.name)
+#'  
+#'  macam.spct
+#'  getWhenMeasured(macam.spct)
+#'  getWhatMeasured(macam.spct)
+#'  cat(comment(macam.spct))
+#' 
 read_macam_dta <- function(file,
                            date = NULL,
                            geocode = NULL,
@@ -42,7 +54,8 @@ read_macam_dta <- function(file,
     label <- paste(label.file, label, sep = "\n")
   }
   
-  file_header <- scan(file = file, nlines = 3, skip = 0, what = "character")
+  file_header <- scan(file = file, nlines = 3, skip = 0,
+                      what = "character", quiet = TRUE)
   if (is.null(date)) {
     date <- lubridate::dmy(sub(pattern = "@", replacement = "",
                                x = file_header[1], fixed = TRUE),
@@ -53,7 +66,7 @@ read_macam_dta <- function(file,
   }
   z <- scan(file = file,
                    what = list(w.length = double(), s.e.irrad = double()),
-                   skip = 3)
+                   skip = 3, quiet = TRUE)
 
   old.opts <- options("photobiology.strict.range" = NA_integer_)
   z <- photobiology::as.source_spct(z, time.unit = "second")
